Transforms helper functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~

The following functions in the `.transforms` module are deprecated,
because they are considerer internal functionality and should not be used
by end users:

- ``matplotlib.transforms.nonsingular``
- ``matplotlib.transforms.interval_contains``
- ``matplotlib.transforms.interval_contains_open``
